@@ -15,9 +15,15 @@ namespace OSM
 	QPointF ll2m(const Coordinates &c);
 	Coordinates m2ll(const QPointF &p);
 	QPoint mercator2tile(const QPointF &m, int zoom);
+	QPointF tile2mercator(const QPoint &p, int zoom);
 	qreal zoom2scale(int zoom, int tileSize);
 	int scale2zoom(qreal scale, int tileSize);
 	qreal resolution(const QPointF &p, int zoom, int tileSize);
+
+	inline Coordinates tile2ll(const QPoint &p, int zoom)
+	  {return m2ll(tile2mercator(p, zoom));}
+	inline QPoint ll2tile(const Coordinates &c, int zoom)
+	  {return mercator2tile(ll2m(c), zoom);}
 }
 
 #endif // OSM_H
